@@ -36,8 +36,8 @@ class Q_DECL_EXPORT BackendInterface : public QObject
     Q_DISABLE_COPY(BackendInterface)
 
 public:
-    explicit BackendInterface(QObject* parent = 0);
-    virtual ~BackendInterface();
+    explicit BackendInterface(QObject* parent = nullptr);
+    ~BackendInterface() override;
 
     /**
      * This enum type defines the different states of the system battery.
